%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                               %%
%%        CEAA russian abstract class            %%
%%                                               %%
%%   Author: Vladimir Bobkov, veld13@gmail.com   %%
%%   $Revision:: 510              $              %%
%%   $Date:: 2020-03-19 01:59:54 #$              %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}

\LoadClass[fontsize=10pt,a5paper]{extarticle}

\RequirePackage{scrextend}
\RequirePackage{indentfirst}
\RequirePackage[T1,T2A]{fontenc}
\RequirePackage[utf8]{inputenc}
\RequirePackage[english,russian]{babel}
\RequirePackage[left=2cm,right=2cm,top=1.5cm,bottom=1.5cm,bindingoffset=0cm]{geometry}
\RequirePackage{tikz}
\RequirePackage{etoolbox}
\RequirePackage[intlimits]{amsmath}

\newcommand\hlw{0.1mm}      %header border single line width
\newcommand\hds{0.9pt}      %header border multiline distance
\newcommand\hout{-0.2cm}    %header outline border width
\newcommand\hvgap{12pt}     %header outline border vertical gap
\newcommand\hhsize{10.94cm} %header border horizontal size
\newcommand\hvsize{68.1pt}  %header border vertical size

\pagenumbering{gobble}      % turn off page numbering

%% Title
\renewcommand{\maketitle}{%
 \newpage
 \begin{flushleft}
  {% header outline
   \begin{tikzpicture}[remember picture, overlay, line width=\hlw]
     \foreach \i in {0,1,2}{
       \coordinate (A) at (\hout+\i*\hds,\hvgap-\i*\hds);
         \path (A)--++(0,-\hvsize+\i*\hds) coordinate (B);
         \path (A)--++(\hhsize-\i*\hds,0) coordinate (C);
         \draw (B)|-(C);
	 }
   \end{tikzpicture}
	
   \selectfont\bfseries
    \MakeUppercase{\@title}
   \par
  }% header outline
  {% authors
   \@author
   \par
  }% authors
  {% authors affiliation
	\fontsize{9}{9}\selectfont
	\def\and{ \\%\vspace{2pt}
	}
   	\normalfont\itshape\@address
   \par
  }% authors affiliation
 \end{flushleft}
 \par
}% End of \@maketitle

\def\author{\@ifnextchar[{\@getshortauthor}{\@getauthor}}
\def\@getauthor#1{\gdef\@author{#1}\gdef\@shortauthor{#1}}
\def\@getshortauthor[#1]#2{\gdef\@shortauthor{#1}\gdef\@author{#2}}

\newcommand{\address}[1]{\gdef\@address{#1}}
\newcommand{\keywords}[1]{\gdef\@keywords{#1}}
\newcommand{\heading}[1]{\gdef\@heading{#1}}

\newcommand{\figref}[1]{рис. \ref{#1}}
\renewcommand{\eqref}[1]{(\ref{#1})}

\newcommand\dst{\displaystyle}

\makeatletter
\renewcommand*{\@biblabel}[1]{\hfill#1.}
\makeatother

\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
  \oldbibliography{#1}%
  \setlength{\itemsep}{-4pt}%
}

\AtBeginDocument{%
  \maketitle
  \let\maketitle\relax
}

\endinput
